==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebColumnTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebColumnTemplateContextDescription } from "./WebColumnTemplateContextDescription";
/**
 * @hidden
 */
export let WebColumnTemplateContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnTemplateContextDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnTemplateContextDescriptionMetadata.a == null) {
                WebColumnTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnTemplateContextDescriptionMetadata.c(WebColumnTemplateContextDescriptionMetadata.a);
            }
            if (a.k(WebColumnTemplateContextDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebColumnTemplateContextDescriptionMetadata.a);
            WebColumnDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ColumnTemplateContext");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Implicit", "ExportedType:WebColumn");
            a.item("Column", "ExportedType:WebColumn");
        }
        static d(a) {
            WebColumnTemplateContextDescriptionMetadata.b(a);
            a.ad("WebColumnTemplateContext", () => new WebColumnTemplateContextDescription());
            a.ac("WebColumnTemplateContext", WebColumnTemplateContextDescriptionMetadata.a);
        }
    }
    WebColumnTemplateContextDescriptionMetadata.$t = /*@__PURE__*/ markType(WebColumnTemplateContextDescriptionMetadata, 'WebColumnTemplateContextDescriptionMetadata');
    WebColumnTemplateContextDescriptionMetadata.a = null;
    return WebColumnTemplateContextDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/WebColumnTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebColumnTemplateContextDescription } from "./WebColumnTemplateContextDescription";
/**
 * @hidden
 */
export let WebColumnTemplateContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnTemplateContextDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnTemplateContextDescriptionMetadata.a == null) {
                WebColumnTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnTemplateContextDescriptionMetadata.c(WebColumnTemplateContextDescriptionMetadata.a);
            }
            if (a.k(WebColumnTemplateContextDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebColumnTemplateContextDescriptionMetadata.a);
            WebColumnDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ColumnTemplateContext");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Implicit", "ExportedType:WebColumn");
            a.item("Column", "ExportedType:WebColumn");
        }
        static d(a) {
            WebColumnTemplateContextDescriptionMetadata.b(a);
            a.ae("WebColumnTemplateContext", () => new WebColumnTemplateContextDescription());
            a.ad("WebColumnTemplateContext", WebColumnTemplateContextDescriptionMetadata.a);
        }
    }
    WebColumnTemplateContextDescriptionMetadata.$t = /*@__PURE__*/ markType(WebColumnTemplateContextDescriptionMetadata, 'WebColumnTemplateContextDescriptionMetadata');
    WebColumnTemplateContextDescriptionMetadata.a = null;
    return WebColumnTemplateContextDescriptionMetadata;
})();
